@@ -338,10 +338,13 @@ class DynamoFL(_Base):
             new_model_path = get_trained_path(project_key, model_path, ext, datasource_key, current_round)
 
             print(f'>>> ({project_key}-{datasource_key}) Training weights on local model...')
-            train(datasource_key, federated_model_path, new_model_path, project_info, hyper_param_values)
+            train_res = train(datasource_key, federated_model_path, new_model_path, project_info, hyper_param_values)
 
             print(f'>>> ({project_key}-{datasource_key}) Uploading round ({current_round}) trained model...')
-            project.push_model(new_model_path, datasource_key)
+            if train_res:
+                project.push_model(new_model_path, datasource_key, params=train_res)
+            else:
+                project.push_model(new_model_path, datasource_key)
             print('Done.')
             print()
 
